@@ -11,12 +11,12 @@ use fil_actors_runtime::{
     actor_error, make_map_with_root_and_bitwidth, wasm_trampoline, ActorDowncast, ActorError,
     Multimap, CRON_ACTOR_ADDR, INIT_ACTOR_ADDR, REWARD_ACTOR_ADDR, SYSTEM_ACTOR_ADDR,
 };
+use fvm_ipld_blockstore::Blockstore;
+use fvm_ipld_encoding::RawBytes;
 use fvm_shared::actor::builtin::{Type, CALLER_TYPES_SIGNABLE};
 use fvm_shared::address::Address;
 use fvm_shared::bigint::bigint_ser::{BigIntDe, BigIntSer};
-use fvm_shared::blockstore::Blockstore;
 use fvm_shared::econ::TokenAmount;
-use fvm_shared::encoding::RawBytes;
 use fvm_shared::error::ExitCode;
 use fvm_shared::reward::ThisEpochRewardReturn;
 use fvm_shared::sector::SealVerifyInfo;
@@ -43,6 +43,8 @@ mod types;
 /// This number is empirically determined
 const GAS_ON_SUBMIT_VERIFY_SEAL: i64 = 34721049;
 
+const ERR_TOO_MANY_PROVE_COMMITS: ExitCode = ExitCode::new(32);
+
 /// Storage power actor methods available
 #[derive(FromPrimitive)]
 #[repr(u64)]
@@ -73,7 +75,7 @@ impl Actor {
 
         let st = State::new(rt.store()).map_err(|e| {
             e.downcast_default(
-                ExitCode::ErrIllegalState,
+                ExitCode::USR_ILLEGAL_STATE,
                 "Failed to create power actor state",
             )
         })?;
@@ -122,7 +124,7 @@ impl Actor {
         rt.transaction(|st: &mut State, rt| {
             let mut claims =
                 make_map_with_root_and_bitwidth(&st.claims, rt.store(), HAMT_BIT_WIDTH).map_err(
-                    |e| e.downcast_default(ExitCode::ErrIllegalState, "failed to load claims"),
+                    |e| e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load claims"),
                 )?;
             set_claim(
                 &mut claims,
@@ -135,7 +137,7 @@ impl Actor {
             )
             .map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     "failed to put power in claimed table while creating miner",
                 )
             })?;
@@ -144,7 +146,7 @@ impl Actor {
             st.update_stats_for_new_miner(window_post_proof_type)
                 .map_err(|e| {
                     actor_error!(
-                        ErrIllegalState,
+                        USR_ILLEGAL_STATE,
                         "failed to update power stats for new miner {}: {}",
                         &id_address,
                         e
@@ -152,7 +154,7 @@ impl Actor {
                 })?;
 
             st.claims = claims.flush().map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush claims")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush claims")
             })?;
             Ok(())
         })?;
@@ -178,7 +180,7 @@ impl Actor {
         rt.transaction(|st: &mut State, rt| {
             let mut claims =
                 make_map_with_root_and_bitwidth(&st.claims, rt.store(), HAMT_BIT_WIDTH).map_err(
-                    |e| e.downcast_default(ExitCode::ErrIllegalState, "failed to load claims"),
+                    |e| e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load claims"),
                 )?;
 
             st.add_to_claim(
@@ -189,7 +191,7 @@ impl Actor {
             )
             .map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     format!(
                         "failed to update power raw {}, qa {}",
                         params.raw_byte_delta, params.quality_adjusted_delta,
@@ -198,7 +200,7 @@ impl Actor {
             })?;
 
             st.claims = claims.flush().map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush claims")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush claims")
             })?;
             Ok(())
         })
@@ -221,7 +223,7 @@ impl Actor {
         // Ensure it is not possible to enter a large negative number which would cause
         // problems in cron processing.
         if params.event_epoch < 0 {
-            return Err(actor_error!(ErrIllegalArgument;
+            return Err(actor_error!(USR_ILLEGAL_ARGUMENT;
                 "cron event epoch {} cannot be less than zero", params.event_epoch));
         }
 
@@ -233,16 +235,16 @@ impl Actor {
                 CRON_QUEUE_AMT_BITWIDTH,
             )
             .map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to load cron events")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load cron events")
             })?;
 
             st.append_cron_event(&mut events, params.event_epoch, miner_event)
                 .map_err(|e| {
-                    e.downcast_default(ExitCode::ErrIllegalState, "failed to enroll cron event")
+                    e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to enroll cron event")
                 })?;
 
             st.cron_event_queue = events.root().map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush cron events")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush cron events")
             })?;
             Ok(())
         })?;
@@ -307,7 +309,7 @@ impl Actor {
             st.add_pledge_total(pledge_delta);
             if st.total_pledge_collateral.is_negative() {
                 return Err(actor_error!(
-                    ErrIllegalState,
+                    USR_ILLEGAL_STATE,
                     "negative total pledge collateral {}",
                     st.total_pledge_collateral
                 ));
@@ -338,7 +340,7 @@ impl Actor {
                 )
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         "failed to load proof batching set",
                     )
                 })?
@@ -355,26 +357,33 @@ impl Actor {
                 .get::<SealVerifyInfo>(&miner_addr.to_bytes())
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         format!("failed to get seal verify infos at addr {}", miner_addr),
                     )
                 })?;
             if let Some(arr) = arr {
                 if arr.count() >= MAX_MINER_PROVE_COMMITS_PER_EPOCH {
-                    return Err(actor_error!(ErrTooManyProveCommits;
-                        "miner {} attempting to prove commit over {} sectors in epoch",
-                        miner_addr, MAX_MINER_PROVE_COMMITS_PER_EPOCH));
+                    return Err(ActorError::new(
+                        ERR_TOO_MANY_PROVE_COMMITS,
+                        format!(
+                            "miner {} attempting to prove commit over {} sectors in epoch",
+                            miner_addr, MAX_MINER_PROVE_COMMITS_PER_EPOCH
+                        ),
+                    ));
                 }
             }
 
             mmap.add(miner_addr.to_bytes().into(), seal_info)
                 .map_err(|e| {
-                    e.downcast_default(ExitCode::ErrIllegalState, "failed to insert proof into set")
+                    e.downcast_default(
+                        ExitCode::USR_ILLEGAL_STATE,
+                        "failed to insert proof into set",
+                    )
                 })?;
 
             let mmrc = mmap.root().map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     "failed to flush proofs batch map",
                 )
             })?;
@@ -569,18 +578,18 @@ impl Actor {
                 CRON_QUEUE_AMT_BITWIDTH,
             )
             .map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to load cron events")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load cron events")
             })?;
 
             let claims =
                 make_map_with_root_and_bitwidth::<_, Claim>(&st.claims, rt.store(), HAMT_BIT_WIDTH)
                     .map_err(|e| {
-                        e.downcast_default(ExitCode::ErrIllegalState, "failed to load claims")
+                        e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load claims")
                     })?;
             for epoch in st.first_cron_epoch..=rt_epoch {
                 let epoch_events = load_cron_events(&events, epoch).map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         format!("failed to load cron events at {}", epoch),
                     )
                 })?;
@@ -595,7 +604,7 @@ impl Actor {
                             .contains_key(&evt.miner_addr.to_bytes())
                             .map_err(|e| {
                                 e.downcast_default(
-                                    ExitCode::ErrIllegalState,
+                                    ExitCode::USR_ILLEGAL_STATE,
                                     "failed to look up claim",
                                 )
                             })?;
@@ -608,7 +617,7 @@ impl Actor {
 
                 events.remove_all(&epoch_key(epoch)).map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         format!("failed to clear cron events at {}", epoch),
                     )
                 })?;
@@ -616,7 +625,7 @@ impl Actor {
 
             st.first_cron_epoch = rt_epoch + 1;
             st.cron_event_queue = events.root().map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush events")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush events")
             })?;
 
             Ok(())
@@ -653,7 +662,7 @@ impl Actor {
                 let mut claims =
                     make_map_with_root_and_bitwidth(&st.claims, rt.store(), HAMT_BIT_WIDTH)
                         .map_err(|e| {
-                            e.downcast_default(ExitCode::ErrIllegalState, "failed to load claims")
+                            e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load claims")
                         })?;
 
                 // Remove power and leave miner frozen
@@ -670,7 +679,7 @@ impl Actor {
                 }
 
                 st.claims = claims.flush().map_err(|e| {
-                    e.downcast_default(ExitCode::ErrIllegalState, "failed to flush claims")
+                    e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush claims")
                 })?;
                 Ok(())
             })?;
@@ -723,7 +732,7 @@ impl ActorCode for Actor {
                 let res = Self::current_total_power(rt)?;
                 Ok(RawBytes::serialize(res)?)
             }
-            None => Err(actor_error!(SysErrInvalidMethod; "Invalid method")),
+            None => Err(actor_error!(SYS_INVALID_METHOD; "Invalid method")),
         }
     }
 }
