@@ -9,14 +9,14 @@ use fil_actors_runtime::{
     actor_error, consensus_miner_min_power, make_empty_map, make_map_with_root,
     make_map_with_root_and_bitwidth, ActorDowncast, ActorError, Map, Multimap,
 };
+use fvm_ipld_blockstore::Blockstore;
+use fvm_ipld_encoding::tuple::{Deserialize_tuple, Serialize_tuple};
+use fvm_ipld_encoding::{Cbor, RawBytes};
 use fvm_ipld_hamt::BytesKey;
 use fvm_shared::address::Address;
 use fvm_shared::bigint::{bigint_ser, BigInt};
-use fvm_shared::blockstore::Blockstore;
 use fvm_shared::clock::ChainEpoch;
 use fvm_shared::econ::TokenAmount;
-use fvm_shared::encoding::tuple::*;
-use fvm_shared::encoding::{Cbor, RawBytes};
 use fvm_shared::error::ExitCode;
 use fvm_shared::sector::{RegisteredPoStProof, StoragePower};
 use fvm_shared::smooth::{AlphaBetaFilter, FilterEstimate, DEFAULT_ALPHA, DEFAULT_BETA};
@@ -83,7 +83,7 @@ impl State {
             .root()
             .map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     "Failed to get empty multimap cid",
                 )
             })?;
@@ -146,7 +146,7 @@ impl State {
         qa_power: &StoragePower,
     ) -> anyhow::Result<()> {
         let old_claim = get_claim(claims, miner)?
-            .ok_or_else(|| actor_error!(ErrNotFound, "no claim for actor {}", miner))?;
+            .ok_or_else(|| actor_error!(USR_NOT_FOUND, "no claim for actor {}", miner))?;
 
         self.total_qa_bytes_committed += qa_power;
         self.total_bytes_committed += power;
@@ -185,21 +185,21 @@ impl State {
 
         if new_claim.raw_byte_power.is_negative() {
             return Err(anyhow!(actor_error!(
-                ErrIllegalState,
+                USR_ILLEGAL_STATE,
                 "negative claimed raw byte power: {}",
                 new_claim.raw_byte_power
             )));
         }
         if new_claim.quality_adj_power.is_negative() {
             return Err(anyhow!(actor_error!(
-                ErrIllegalState,
+                USR_ILLEGAL_STATE,
                 "negative claimed quality adjusted power: {}",
                 new_claim.quality_adj_power
             )));
         }
         if self.miner_above_min_power_count < 0 {
             return Err(anyhow!(actor_error!(
-                ErrIllegalState,
+                USR_ILLEGAL_STATE,
                 "negative amount of miners lather than min: {}",
                 self.miner_above_min_power_count
             )));
@@ -275,15 +275,15 @@ impl State {
     where
         BS: Blockstore,
     {
-        let claims = make_map_with_root::<_, Claim>(&self.claims, store)
-            .map_err(|e| e.downcast_default(ExitCode::ErrIllegalState, "failed to load claims"))?;
+        let claims = make_map_with_root::<_, Claim>(&self.claims, store).map_err(|e| {
+            e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load claims")
+        })?;
 
-        if !claims
-            .contains_key(&miner_addr.to_bytes())
-            .map_err(|e| e.downcast_default(ExitCode::ErrIllegalState, "failed to look up claim"))?
-        {
+        if !claims.contains_key(&miner_addr.to_bytes()).map_err(|e| {
+            e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to look up claim")
+        })? {
             return Err(actor_error!(
-                ErrForbidden,
+                USR_FORBIDDEN,
                 "unknown miner {} forbidden to interact with power actor",
                 miner_addr
             ));
@@ -299,7 +299,7 @@ impl State {
         let claims =
             make_map_with_root_and_bitwidth::<_, Claim>(&self.claims, store, HAMT_BIT_WIDTH)
                 .map_err(|e| {
-                    e.downcast_default(ExitCode::ErrIllegalState, "failed to load claims")
+                    e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load claims")
                 })?;
 
         let claim = get_claim(&claims, miner)?;
@@ -365,14 +365,14 @@ pub fn set_claim<BS: Blockstore>(
 ) -> anyhow::Result<()> {
     if claim.raw_byte_power.is_negative() {
         return Err(anyhow!(actor_error!(
-            ErrIllegalState,
+            USR_ILLEGAL_STATE,
             "negative claim raw power {}",
             claim.raw_byte_power
         )));
     }
     if claim.quality_adj_power.is_negative() {
         return Err(anyhow!(actor_error!(
-            ErrIllegalState,
+            USR_ILLEGAL_STATE,
             "negative claim quality-adjusted power {}",
             claim.quality_adj_power
         )));
